# CUE to Audacity Label Converter

Ein Python-Script, das CUE-Dateien (von rekordbox DJ oder anderen Quellen) in Audacity-Label-Dateien umwandelt.

## Beschreibung

Dieses Tool liest CUE-Dateien und erstellt daraus Textdateien mit Zeitstempeln und Track-Titeln, die direkt in Audacity als Label-Track importiert werden können. Besonders nützlich für DJ-Sets oder lange Audio-Aufnahmen, die in einzelne Tracks unterteilt werden sollen.

## Features

- Unterstützt rekordbox CUE-Dateien im HH:MM:SS Format
- Automatische Erkennung von Standard CUE-Formaten (MM:SS:FF mit CD-Frames)
- Flexible Regex-Pattern für verschiedene Einrückungen (Tabs/Leerzeichen)
- UTF-8 Encoding für internationale Zeichen
- Plattformübergreifend (Windows, macOS, Linux)

## Installation

### Voraussetzungen
- Python 3.6 oder höher
- Keine externen Abhängigkeiten (nutzt nur Standard-Bibliotheken)

### Setup
```bash
git clone <repository-url>
cd cue2auda
```

Oder einfach die Dateien herunterladen:
- `cue2auda.py` (Hauptscript)
- `requirements.txt` (optional)

## Verwendung

```bash
python cue2auda.py /pfad/zu/ihren/cue/dateien
```

### Beispiel
```bash
python cue2auda.py .
```
Verarbeitet alle `.cue` Dateien im aktuellen Verzeichnis.

## Ein- und Ausgabeformat

### Eingabe (CUE-Datei)
```
TRACK 01 AUDIO
    TITLE "Song Title"
    PERFORMER "Artist Name"
    INDEX 01 00:02:30
```

### Ausgabe (TXT-Datei für Audacity)
```
150.000000    150.000000    Song Title
```

## Unterstützte CUE-Formate

1. **rekordbox Format**: `HH:MM:SS` (Stunden:Minuten:Sekunden)
2. **Standard CUE Format**: `MM:SS:FF` (Minuten:Sekunden:Frames, 75 Frames pro Sekunde)

Das Script erkennt automatisch das Format basierend auf den Zeitwerten.

## Audacity Import

1. Öffnen Sie Ihre Audio-Datei in Audacity
2. Gehen Sie zu `Datei` → `Importieren` → `Labels...`
3. Wählen Sie die generierte `.txt` Datei aus
4. Die Zeitmarken erscheinen als Label-Track

## Dateien

- `cue2auda.py` - Hauptscript
- `requirements.txt` - Python-Abhängigkeiten (leer, da nur Standard-Bibliotheken verwendet werden)
- `README.md` - Diese Datei

## Beispiel-Workflow

1. Exportieren Sie ein DJ-Set aus rekordbox mit CUE-Datei
2. Führen Sie das Script aus: `python cue2auda.py /pfad/zu/cue/dateien`
3. Importieren Sie die generierte `.txt` Datei in Audacity
4. Nutzen Sie die Labels zum Schneiden oder Navigieren

## Technische Details

- **Zeitformat**: Absolute Zeitstempel in Sekunden vom Anfang der Aufnahme
- **Encoding**: UTF-8 für internationale Zeichen
- **Kompatibilität**: Funktioniert mit Tab- und Leerzeichen-Einrückung

## Fehlerbehebung

### Leere Ausgabedatei
- Überprüfen Sie das Format Ihrer CUE-Datei
- Stellen Sie sicher, dass `TITLE` und `INDEX 01` Zeilen vorhanden sind

### Falsche Zeitstempel
- Das Script erkennt automatisch HH:MM:SS vs MM:SS:FF Format
- Bei Problemen überprüfen Sie die Debug-Ausgaben

## Autor

Manuel Weiser  
Datum: 2025-07-03

Basierend auf dem ursprünglichen Script von Fabrice Baro (2019-10-24)

## Lizenz

Frei verfügbar für persönliche und kommerzielle Nutzung.
